@@ -1,6 +1,5 @@
 import re
 
-from docutils.parsers.rst import roles
 from docutils import nodes, utils
 
 
@@ -11,11 +10,22 @@ issue_types = {
     'support': '4070A0',
 }
 
+def issue_nodelist(name, link=None):
+    which = '[<span style="color: #%s;">%s</span>]' % (
+        issue_types[name], name.capitalize()
+    )
+    signifier = [nodes.raw(text=which, format='html')]
+    hyperlink = [nodes.inline(text=" "), link] if link else []
+    trail = [] if link else [nodes.inline(text=" ")]
+    return signifier + hyperlink + [nodes.inline(text=":")] + trail
+
+
 def issues_role(name, rawtext, text, lineno, inliner, options={}, content=[]):
     """
     Use: :issue|bug|feature|support:`ticket_number`
 
-    When invoked as :issue:, turns into just a "#NN" hyperlink to Github.
+    When invoked as :issue:, turns into just a "#NN" hyperlink to
+    `releases_issue_uri`.
 
     When invoked otherwise, turns into "[Type] <#NN hyperlink>: ".
 
@@ -24,7 +34,6 @@ def issues_role(name, rawtext, text, lineno, inliner, options={}, content=[]):
     prior to parsing. May also give 'major' in the same vein, implying the bug
     was a major bug released in a feature release.
     """
-    #from ipdb import set_trace; set_trace()
     # Old-style 'just the issue link' behavior
     issue_no, _, ported = utils.unescape(text).partition(' ')
     # Lol @ access back to Sphinx
@@ -33,15 +42,7 @@ def issues_role(name, rawtext, text, lineno, inliner, options={}, content=[]):
     link = nodes.reference(rawtext, '#' + issue_no, refuri=ref, **options)
     # Additional 'new-style changelog' stuff
     if name in issue_types:
-        which = '[<span style="color: #%s;">%s</span>]' % (
-            issue_types[name], name.capitalize()
-        )
-        nodelist = [
-            nodes.raw(text=which, format='html'),
-            nodes.inline(text=" "),
-            link,
-            nodes.inline(text=":")
-        ]
+        nodelist = issue_nodelist(name, link)
         # Sanity check
         if ported not in ('backported', 'major', ''):
             raise ValueError("Gave unknown issue metadata '%s' for issue no. %s" % (ported, issue_no))
@@ -140,11 +141,9 @@ def construct_releases(entries, app):
         # Release lines should have an empty 'rest' so it's ignored.
         if isinstance(focus, release):
             line = get_line(focus)
-            print "%s (%s)" % (focus.number, line)
             # New release line/branch detected. Create it & dump unreleased into
             # this new release. Skip non-major bugs.
             if line not in lines:
-                print "> Is new line"
                 lines[line] = []
                 releases.append({
                     'obj': focus,
@@ -155,19 +154,14 @@ def construct_releases(entries, app):
                     ]
                 })
                 lines['unreleased'] = []
-                print "> After dump, lines: %r" % (lines,)
-                print "> And releases: %r" % (releases,)
             # Existing line -> empty out its bucket into new release.
             # Skip 'major' bugs as those "belong" to the next release.
             else:
-                print "> Existing line"
                 releases.append({
                     'obj': focus,
                     'entries': [x for x in lines[line] if not x.major],
                 })
                 lines[line] = []
-                print "> After dump, lines: %r" % (lines,)
-                print "> And releases: %r" % (releases,)
         # Entries get copied into release line buckets as follows:
         # * Everything goes into 'unreleased' so it can be used in new lines.
         # * Bugfixes (but not support or feature entries) go into all release
@@ -182,35 +176,36 @@ def construct_releases(entries, app):
             # Handle rare-but-valid non-issue-attached line items, which are
             # always bugs. (They are their own description.)
             if not isinstance(focus, issue):
-                focus = issue(type_='bug', nodelist=[focus], backported=False, major=False, description=[focus])
+                focus = issue(
+                    type_='bug',
+                    nodelist=issue_nodelist('bug'),
+                    backported=False,
+                    major=False,
+                    description=[focus]
+                )
             else:
                 focus.attributes['description'] = rest
-            print "%s %s (backported=%s, major=%s)" % (focus.type, focus.number, focus.backported, focus.major)
             if focus.type == 'bug':
                 # Regular bugs go into per-line buckets only.
                 if not focus.major:
                     for line in [x for x in lines if x != 'unreleased']:
-                        print "> Appending to %r" % line
                         lines[line].append(focus)
                 # Major bugs go into feature release bucket only.
                 else:
-                    print "> Appending to 'unreleased'"
                     lines['unreleased'].append(focus)
             else:
                 # Backported feature/support items go into all lines.
                 if focus.backported:
                     for line in lines:
-                        print "> Appending to %r" % line
                         lines[line].append(focus)
                 # Non-backported feature/support items go into feature releases
                 # only.
                 else:
-                    print "> Appending to 'unreleased'"
                     lines['unreleased'].append(focus)
 
     # Entries not yet released get special 'release' entries (that lack an
     # actual release object).
-    nodelist = [release_nodes("Unreleased", "master", None, app.config)]
+    nodelist = [release_nodes("Unreleased", 'master', None, app.config)]
     releases.append({
         'obj': release(number='unreleased', date=None, nodelist=nodelist),
         'entries': lines['unreleased']
